Macroeconomic Models 
===================== 
 
This section includes planned macroeconomic models. Contributions are welcome! 
 
- IS-LM Model 
- AD-AS Model 
- Solow Growth Model 
- New Keynesian Models 
- RBC (Real Business Cycle) Model 
- DSGE (Dynamic Stochastic General Equilibrium) Models 
